@@ -27,9 +27,18 @@ DEFAULT_CONFIG = {
     'sink1': {
         'type': "mqtt",
         'host': "localhost",
+        'port': 1883,
+        'tls': False,
+        'ca_file_path': "",
+        'check_hostname': True,
+        'username': "",
+        'password': "",
+        'client_cert_path': "",
+        'client_key_path': "",
     },
     'logging': {
         'default': 'DEBUG',
+        'collector': 'DEBUG',
         'smartmeter': 'DEBUG',
         'sink': 'DEBUG',
     }
@@ -55,5 +64,5 @@ def get_default_config() -> configparser.ConfigParser:
 
 def write_default_config(config_path: str):
     config = get_default_config()
-    with open(config_path, 'w') as file:
+    with open(config_path, 'w', encoding='utf-8') as file:
         config.write(file, True)
